==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Draw/Text/ts/Text_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../TextDialog/CharacterMapDialog.ui" line="+14"/>
        <source>Character Map</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Text</name>
    <message>
        <location filename="../Text.js" line="+88"/>
        <source>Position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Text.ui" line="+17"/>
        <source>Contents:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Height:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Angle:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TextInit.js" line="+2"/>
        <source>&amp;Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw text</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TextDialog</name>
    <message>
        <location filename="../TextDialog/TextDialog.js" line="+242"/>
        <source>Default value:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+255"/>
        <source>&amp;Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Redo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Cu&amp;t</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Bold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Italic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Subscript</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Superscript</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+18"/>
        <source>&amp;Color...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Special Characters...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+310"/>
        <source>Others...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+129"/>
        <source>Degree</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plus-Minus</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Diameter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Almost equal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Multiplication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Division</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Identity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Not equal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ohm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Omega</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Squared</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cubed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TextDialog/TextDialog.ui" line="+14"/>
        <source>Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Main Font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Height:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Text Height in Drawing Units</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+18"/>
        <location line="+213"/>
        <source>Bold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-206"/>
        <location line="+219"/>
        <source>Italic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-205"/>
        <source>Text fits on one line and has no formatting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Simple text
(one line, no formatting)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Rich Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+115"/>
        <source>Ctrl+B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Ctrl+I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Insert Symbol...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Attribute Details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Tag:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Prompt:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Value:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Text Geometry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Line spacing factor:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Line Spacing Factor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Angle:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Rotation Angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Alignment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Bottom Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Bottom Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Top Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Middle Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Base Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Top Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Base Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Base Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Middle Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Bottom Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Middle Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Top Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+88"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Draw/Text/ts/Text_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../TextDialog/CharacterMapDialog.ui" line="+14"/>
        <source>Character Map</source>
        <translation>Speciale tekens</translation>
    </message>
</context>
<context>
    <name>Text</name>
    <message>
        <location filename="../Text.js" line="+88"/>
        <source>Position</source>
        <translation>Positie</translation>
    </message>
    <message>
        <location filename="../Text.ui" line="+17"/>
        <source>Contents:</source>
        <translation>Inhoud:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Height:</source>
        <translation>Hoogte:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Angle:</source>
        <translation>Hoek:</translation>
    </message>
    <message>
        <location filename="../TextInit.js" line="+2"/>
        <source>&amp;Text</source>
        <translation>&amp;Tekst</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw text</source>
        <translation>Tekst tekenen</translation>
    </message>
</context>
<context>
    <name>TextDialog</name>
    <message>
        <location filename="../TextDialog/TextDialog.js" line="+242"/>
        <source>Default value:</source>
        <translation>Standaardwaarde:</translation>
    </message>
    <message>
        <location line="+260"/>
        <source>&amp;Undo</source>
        <translation>&amp;Herstel</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Redo</source>
        <translation>&amp;Opnieuw</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Cu&amp;t</source>
        <translation>&amp;Knip</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopieer</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Paste</source>
        <translation>&amp;Plak</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Bold</source>
        <translation>&amp;Vetgedrukt</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Italic</source>
        <translation>&amp;Cursief</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Subscript</source>
        <translation>&amp;Onderschrift</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Superscript</source>
        <translation>&amp;Bovenschrift</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>&amp;Color...</source>
        <translation>&amp;Kleur...</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Special Characters...</source>
        <translation>&amp;Speciale tekens...</translation>
    </message>
    <message>
        <location line="+310"/>
        <source>Others...</source>
        <translation>Andere...</translation>
    </message>
    <message>
        <location line="+131"/>
        <source>Degree</source>
        <translation>Graad</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plus-Minus</source>
        <translation>Plus-minus</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Diameter</source>
        <translation>Diameter</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Almost equal</source>
        <translation>Ongeveer gelijk</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Multiplication</source>
        <translation>Vermenigvuldiging</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Division</source>
        <translation>Divisie</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delta</source>
        <translation>Delta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pi</source>
        <translation>Pi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Identity</source>
        <translation>Identiteit</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Not equal</source>
        <translation>Niet gelijk</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ohm</source>
        <translation>Ohm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Omega</source>
        <translation>Omega</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Squared</source>
        <translation>Kwadraat</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cubed</source>
        <translation>Cubed</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No-break space</source>
        <translation>Harde spatie</translation>
    </message>
    <message>
        <location filename="../TextDialog/TextDialog.ui" line="+14"/>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Main Font</source>
        <translation>Hoofd font</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Height:</source>
        <translation>Hoogte:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Text Height in Drawing Units</source>
        <translation>Teksthoogte</translation>
    </message>
    <message>
        <location line="+18"/>
        <location line="+213"/>
        <source>Bold</source>
        <translation>Vetgedrukt</translation>
    </message>
    <message>
        <location line="-206"/>
        <location line="+219"/>
        <source>Italic</source>
        <translation>Cursief</translation>
    </message>
    <message>
        <location line="-205"/>
        <source>Text fits on one line and has no formatting</source>
        <translation>Tekst past op één lijn en heeft geen formattering</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Simple text
(one line, no formatting)</source>
        <translation>Eenvoudige tekst
(een lijn, geen formattering)</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Rich Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Cut</source>
        <translation>Knip</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Copy</source>
        <translation>Kopieer</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Paste</source>
        <translation>Plak</translation>
    </message>
    <message>
        <location line="+115"/>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Insert Symbol...</source>
        <translation>Voeg symbool in...</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Source</source>
        <translation>Bron</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Attribute Details</source>
        <translation>Attribuut gegevens</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Tag:</source>
        <translation>Tag:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Prompt:</source>
        <translation>Prompt:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Value:</source>
        <translation>Waarde:</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Text Geometry</source>
        <translation>Tekstgeometrie</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Line spacing factor:</source>
        <translation>Lijn tussenafstand factor:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Line Spacing Factor</source>
        <translation>Lijn tussenafstand factor</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Angle:</source>
        <translation>Hoek:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Rotation Angle</source>
        <translation>Rotatie hoek</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Alignment</source>
        <translation>Uitlijning</translation>
    </message>
    <message>
        <location line="+311"/>
        <source>Bottom Left</source>
        <translation>Onder links</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Bottom Center</source>
        <translation>Onder center</translation>
    </message>
    <message>
        <location line="-261"/>
        <source>Top Center</source>
        <translation>Boven center</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Middle Right</source>
        <translation>Midden rechts</translation>
    </message>
    <message>
        <location line="+116"/>
        <source>Base Left</source>
        <translation>Basis links</translation>
    </message>
    <message>
        <location line="-177"/>
        <source>Top Left</source>
        <translation>Boven links</translation>
    </message>
    <message>
        <location line="+206"/>
        <source>Base Center</source>
        <translation>Basis center</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Base Right</source>
        <translation>Basis rechts</translation>
    </message>
    <message>
        <location line="-116"/>
        <source>Middle Center</source>
        <translation>Midden center</translation>
    </message>
    <message>
        <location line="+203"/>
        <source>Bottom Right</source>
        <translation>Onder rechts</translation>
    </message>
    <message>
        <location line="-174"/>
        <source>Middle Left</source>
        <translation>Midden links</translation>
    </message>
    <message>
        <location line="-58"/>
        <source>Top Right</source>
        <translation>Boven rechts</translation>
    </message>
    <message>
        <location line="+291"/>
        <source>Cancel</source>
        <translation>Annuleer</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
</TS>
